@@ -14,7 +14,7 @@ from typing import (
 
 from aiohttp import BasicAuth, ClientSession, TCPConnector
 
-from base.model import Model
+from ai_openchat.model import Model
 from base.session import BaseSession
 
 _ProxyBasic = Union[str, Tuple[str, BasicAuth]]
